pitchtools.InversionEquivalentChromaticIntervalClassSet
=======================================================

.. autoclass:: abjad.tools.pitchtools.InversionEquivalentChromaticIntervalClassSet
   :members:
   :undoc-members:
   :show-inheritance:
